Module socialization.ccs.base_goddess_service
=============================================

Classes
-------

`BaseGoddessService(port=9000)`
:   

    ### Ancestors (in MRO)

    * socialization.ccs.json_ws_passive_service.JSONWebsocketPassiveService

    ### Descendants

    * socialization.ccs.wrapped_goddess_service.WrappedGoddessService